.. my_package documentation master file, created by
   sphinx-quickstart on Tue Sep 21 08:07:48 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

**my-package**
===============

.. automodule:: my_package

Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Getting started:

   installation
   overview
   CHANGELOG

.. toctree::
   :hidden:
   :caption: Development

   License <https://raw.githubusercontent.com/allenai/python-package-template/main/LICENSE>
   CONTRIBUTING
   GitHub Repository <https://github.com/allenai/python-package-template>

Team
----

**my-package** is developed and maintained by the AllenNLP team, backed by
`the Allen Institute for Artificial Intelligence (AI2) <https://allenai.org/>`_.
AI2 is a non-profit institute with the mission to contribute to humanity through high-impact AI research and engineering.
To learn more about who specifically contributed to this codebase, see
`our contributors <https://github.com/allenai/python-package-template/graphs/contributors>`_ page.

License
-------

**my-package** is licensed under `Apache 2.0 <https://www.apache.org/licenses/LICENSE-2.0>`_.
A full copy of the license can be found `on GitHub <https://github.com/allenai/python-package-template/blob/main/LICENSE>`_.

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
